@@ -38,7 +38,7 @@ static int atm_parse_opt(struct qdisc_util *qu, int argc, char **argv, struct nl
 static void explain(void)
 {
 	fprintf(stderr, "Usage: ... atm ( pvc ADDR | svc ADDR [ sap SAP ] ) "
-	    "[ qos QOS ] [ hdr HEX... ]\n");
+	    "[ qos QOS ] [ hdr HEX... ] [ excess ( CLASSID | clp ) ] \n");
 }
 
 
@@ -49,6 +49,7 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 	struct atm_qos qos;
 	struct atm_sap sap;
 	unsigned char hdr[MAX_HDR_LEN];
+	__u32 excess;
 	struct rtattr *tail;
 	int hdr_len = -1;
 	int s;
@@ -94,13 +95,14 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 
 			NEXT_ARG();
 			ptr = hdr;
-			for (walk = *argv; *walk; walk += 2) {
+			for (walk = *argv; *walk; walk++) {
 				int tmp;
 
 				if (ptr == hdr+MAX_HDR_LEN) {
 					fprintf(stderr,"header is too long\n");
 					return -1;
 				}
+				if (*walk == '.') continue;
 				if (!isxdigit(walk[0]) || !walk[1] ||
 				    !isxdigit(walk[1])) {
 					explain();
@@ -108,9 +110,18 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 				}
 				sscanf(walk,"%2x",&tmp);
 				*ptr++ = tmp;
+				walk++;
 			}
 			hdr_len = ptr-hdr;
 		}
+		else if (!strcmp(*argv,"excess")) {
+			NEXT_ARG();
+			if (!strcmp(*argv,"clp")) excess = 0;
+			else if (get_tc_classid(&excess,*argv)) {
+					explain();
+					return -1;
+				}
+		}
 		else {
 			explain();
 			return 1;
@@ -140,6 +151,7 @@ static int atm_parse_class_opt(struct qdisc_util *qu, int argc, char **argv,
 	tail = (struct rtattr *) (((void *) n)+NLMSG_ALIGN(n->nlmsg_len));
 	addattr_l(n,1024,TCA_OPTIONS,NULL,0);
 	addattr_l(n,1024,TCA_ATM_FD,&s,sizeof(s));
+	addattr_l(n,1024,TCA_ATM_EXCESS,&excess,sizeof(excess));
 	if (hdr_len != -1) addattr_l(n,1024,TCA_ATM_HDR,hdr,hdr_len);
 	tail->rta_len = (((void *) n)+NLMSG_ALIGN(n->nlmsg_len))-(void *) tail;
 	return 0;
@@ -155,17 +167,45 @@ static int atm_print_opt(struct qdisc_util *qu, FILE *f, struct rtattr *opt)
 	if (!opt) return 0;
 	memset(tb, 0, sizeof(tb));
 	parse_rtattr(tb, TCA_ATM_MAX, RTA_DATA(opt), RTA_PAYLOAD(opt));
-	if (!tb[TCA_ATM_ADDR]) return 0;
-	if (RTA_PAYLOAD(tb[TCA_ATM_ADDR]) < sizeof(struct sockaddr_atmpvc)) {
-		fprintf(stderr,"ATM: address too short\n");
-		return 0;
+	if (tb[TCA_ATM_ADDR])
+		if (RTA_PAYLOAD(tb[TCA_ATM_ADDR]) <
+		    sizeof(struct sockaddr_atmpvc))
+			fprintf(stderr,"ATM: address too short\n");
+		else {
+			if (atm2text(buffer,MAX_ATM_ADDR_LEN,
+			    RTA_DATA(tb[TCA_ATM_ADDR]),A2T_PRETTY | A2T_NAME) <
+			    0) fprintf(stderr,"atm2text error\n");
+			fprintf(f,"pvc %s",buffer);
+		}
+	if (tb[TCA_ATM_HDR]) {
+		int i;
+
+		fprintf(f,"hdr");
+		for (i = 0; i < RTA_PAYLOAD(tb[TCA_ATM_HDR]); i++)
+			fprintf(f,"%c%02x",i ? '.' : ' ',
+			    ((unsigned char *) RTA_DATA(tb[TCA_ATM_HDR]))[i]);
+		if (!i) fprintf(f," .");
+	}
+	if (tb[TCA_ATM_EXCESS]) {
+		__u32 excess;
+
+		if (RTA_PAYLOAD(tb[TCA_ATM_EXCESS]) < sizeof(excess))
+			fprintf(stderr,"ATM: excess class ID too short\n");
+		else {
+			excess = *(__u32 *) RTA_DATA(tb[TCA_ATM_EXCESS]);
+			if (!excess) fprintf(f,"excess clp ");
+			else {
+				char buf[64];
+
+				print_tc_classid(buf,sizeof(buf),excess);
+				fprintf(f,"excess %s ",buf);
+			}
+		}
 	}
-	if (atm2text(buffer,MAX_ATM_ADDR_LEN,RTA_DATA(tb[TCA_ATM_ADDR]),
-	    A2T_PRETTY | A2T_NAME) < 0) fprintf(stderr,"atm2text error\n");
-	printf("%s",buffer);
 	return 0;
 }
 
+
 static int atm_print_xstats(struct qdisc_util *qu, FILE *f, struct rtattr *xstats)
 {
 	return 0;
@@ -182,4 +222,3 @@ struct qdisc_util atm_util = {
 	atm_parse_class_opt,
 	atm_print_opt
 };
-
