@@ -198,11 +198,11 @@ timer_get_expiration(HANDLE timer_handle)
 
   if (to_get->alarm_time) {
     gettimeofday(&g_timer, &tz);
-    EVENT(EM_TIMER,("G_timer:%d sec %d usec\n",
-		    g_timer.tv_sec,g_timer.tv_usec));
-    EVENT(EM_TIMER,("Timer  :%d sec %d usec\n",
-		    to_get->alarm_time->tv_sec,
-		    to_get->alarm_time->tv_usec));
+    EVENT(EM_TIMER,("G_timer:%ld sec %ld usec\n",
+		    (long)g_timer.tv_sec,(long)g_timer.tv_usec));
+    EVENT(EM_TIMER,("Timer  :%ld sec %ld usec\n",
+		    (long)to_get->alarm_time->tv_sec,
+		    (long)to_get->alarm_time->tv_usec));
     if (g_timer.tv_sec > (to_get->alarm_time)->tv_sec || 
 	(g_timer.tv_sec == (to_get->alarm_time)->tv_sec &&
 	 g_timer.tv_usec >= (to_get->alarm_time)->tv_usec)) {
@@ -217,7 +217,8 @@ timer_get_expiration(HANDLE timer_handle)
 	g_timer.tv_usec = 
 	  (to_get->alarm_time)->tv_usec - g_timer.tv_usec;
     }
-    EVENT(EM_TIMER,("Return:%d sec %d usec\n",g_timer.tv_sec,g_timer.tv_usec));
+    EVENT(EM_TIMER,("Return:%ld sec %ld usec\n",
+		    (long)g_timer.tv_sec,(long)g_timer.tv_usec));
     return &g_timer;
   } else
     return NULL;
@@ -248,10 +249,10 @@ timer_usage(void)
 
   printf("Timer usage:\n");
   for(tmp=timerlist;tmp;tmp=tmp->next)
-    printf("\tCallback %p Context:%p %d sec %d usec\n",
+    printf("\tCallback %p Context:%p %ld sec %ld usec\n",
 	   tmp->callback, tmp->context, 
-	   tmp->alarm_time?tmp->alarm_time->tv_sec:0,
-	   tmp->alarm_time?tmp->alarm_time->tv_usec:0);
+	   tmp->alarm_time?(long)tmp->alarm_time->tv_sec:0,
+	   tmp->alarm_time?(long)tmp->alarm_time->tv_usec:0);
 }
 
 /*
