@@ -1,6 +1,6 @@
 /* atmdump.c - ATM raw cell dumper */
 
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -12,7 +12,6 @@
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <netinet/in.h> /* for htonl and ntohl */
-#include <linux/atm.h>
 #include <atm.h>
 
 
