@@ -27,6 +27,10 @@ _syscall3(int,poll,struct pollfd *,ufds,unsigned int,nfds,int,timeout);
 #include "io.h"
 #include "get_vars.h"
 
+#ifdef BROKEN_POLL
+#include "poll2select.h"
+#endif
+
 #define POLL_TIMEOUT 5000    /* poll() timeout, 5 seconds */
 
 #if 1
@@ -106,7 +110,11 @@ void main_loop(int listen_socket)
         while (1) {
                 kernel_ok = mps_ok = new_ctrl = new_shortcut = 1;
                 fflush(stdout);
+#ifdef BROKEN_POLL
+                changed_fds = poll2select(fds, fds_used, poll_timeout);
+#else
                 changed_fds = poll(fds, fds_used, poll_timeout);
+#endif
 #if 0
                 printf("\nio.c: main_loop() poll returns %d\n", changed_fds);
                 for (i = 0; i < OPEN_MAX; i++) {
@@ -122,7 +130,7 @@ void main_loop(int listen_socket)
                 case -1:
                         printf("mpcd: io.c: main_loop: poll error: %s\n", strerror(errno));
 			if(errno == EINTR) continue;
-                        return; /* return to main() */
+                        goto out; /* return to main() */
                         break; /* not reached */
                 case 0:
 			keep_alive_sm(0, -1);  /* (keepalive_liftime, seq_num) */
@@ -203,6 +211,7 @@ void main_loop(int listen_socket)
 			
         }
         
+ out:
         /* clean up, close the sockets */
         for (i = 0; i < fds_used; i++) {
                 if (fds[i].fd < 0)
@@ -221,7 +230,11 @@ void main_loop(int listen_socket)
  */
 static void wait_for_mps_ctrl_addr(){
 	while(!mpc_control.mps_ctrl_addr_set){
+#ifdef BROKEN_POLL
+                if(poll2select(fds, 1, -1))
+#else
 	        if(poll(fds, 1, -1))
+#endif
 		        msg_from_kernel(fds[0].fd);
 	}
 	return;
@@ -713,6 +726,7 @@ static int create_shortcut(char *atm_addr, struct atm_qos qos)
         memcpy(addr.sas_addr.prv, atm_addr, ATM_ESA_LEN);
 	s = get_socket(&mpc_control.data_listen_addr);
 	if(qos.txtp.traffic_class > ATM_UBR || qos.rxtp.traffic_class > ATM_UBR){
+	        printf("mpcd: io.c: create_shortcut() setting qos params (cbr)\n");
 	        if (setsockopt(s, SOL_ATM,SO_ATMQOS, &qos, sizeof(qos)) < 0){
 		        printf("mpcd: io.c: setsockopt SO_ATMQOS failed: %s \n",strerror(errno));
 			close(s);
