@@ -12,7 +12,7 @@
 
 extern struct mpc_control mpc_control;  /* from main.c */
 extern int keep_alive_sm_running;       /* from io.c   */
-
+static unsigned char service_category_to_traff_class(uint32_t service_category);
 #if 0
 #define dprintf printf
 #else
@@ -345,6 +345,8 @@ static int mpoa_resolution_reply( uint8_t * buff ){
   msg.content.in_info.in_dst_ip  = common->dst_protocol_address;
   memcpy(msg.content.in_info.eg_MPC_ATM_addr,cie->cli_nbma_address,ATM_ESA_LEN);
   memcpy(msg.MPS_ctrl,mpc_control.MPS_CTRL_ATM_ADDR, ATM_ESA_LEN);
+  if(values.service_category_present)
+    msg.qos.txtp.traffic_class = service_category_to_traff_class(values.service_category);
   send_to_kernel(&msg);
   keep_alive_sm_running = 1;
   return MPOA_RESOLUTION_REPLY;
@@ -363,6 +365,14 @@ static int checksum_check(uint8_t *buff){
   return 1;
 }
 
+static unsigned char service_category_to_traff_class(uint32_t service_category){
+  unsigned char traffic_class = 0;
+  if(service_category & CBR)
+    traffic_class |= ATM_CBR;
+  else
+    traffic_class |= ATM_UBR;
+  return traffic_class;
+}
 
 int recognize_packet(uint8_t * buff){
   struct nhrp_fixed_h *fixed = (struct nhrp_fixed_h *)buff;
