@@ -3,6 +3,21 @@
 #ifndef PACKETS_H
 #define PACKETS_H
 
+struct mpc_control{
+  int kernel_socket;         /* socket for mpoad <--> kernel messages    */
+  int MPS_socket;            /* MPS control socket for outgoing msgs     */
+  int MPS_listen_socket;     /* listen socket for incoming control calls */
+  int mps_ctrl_addr_set;
+  unsigned char MPS_CTRL_ATM_ADDR[ATM_ESA_LEN];
+  int mps_mac_addr_set;
+  unsigned char MPS_MAC_ADDRESS[13];
+  unsigned char OWN_ATM_ADDRESS[ATM_ESA_LEN];/* Our control ATM address   */
+  struct sockaddr_atmsvc data_listen_addr; /* Our data listen address   */
+  int INTERFACE_NUMBER;                    /* Interface number, x for lecx */
+};                                
+
+
+
 /* p_factory.c */
 
 int send_resolution_request(
@@ -41,11 +56,13 @@ int send_purge_reply(
                      uint8_t * pBuff
                      );
 
+unsigned short compute_ip_csum(
+			       unsigned char *addr, 
+			       int count
+			       );
+
 /* p_recogn.c */
 
-/*
- *  Struct is filled by parse_extensions(). 
- */
 
 int recognize_packet( 
 		     uint8_t * pBuff 
@@ -222,6 +239,8 @@ struct dll_header_extension {
   uint8_t dll_header[256];
 } __attribute__ ((packed)); /* without ((packed)) sizeof() was 273 */
 
+ /* struct is filled by parse_extensions() */
+
 struct extension_values{
   uint32_t dll_header_present;
   struct dll_header_extension dll_ext;
