@@ -478,7 +478,7 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 			set_error(sock,cause == ATM_CV_UNALLOC ?
 			  -EADDRNOTAVAIL : cause == ATM_CV_RES_UNAVAIL ||
 #if defined(UNI31) || defined(UNI40)
-			  cause == ATM_CV_UCR_UNAVAIL ||
+			  cause == ATM_CV_UCR_UNAVAIL_NEW ||
 #endif
 			  cause == ATM_CV_NO_ROUTE_DEST ? -EHOSTUNREACH :
 			  cause == ATM_CV_NUM_CHANGED ? -EREMCHG :
